@@ -154,11 +154,11 @@ class MonitoringCenterService(RequestBase, ABC):
         """
         return self.get(f"{self.url}/api/wb/registered-equipment").json()
 
-    def get_dy_sign(self, url, uid):
-        return self.post("http://django.oa.douwangkeji.com/inside/douyin/signature", data = {
-                'url': url,
-                'uid': uid
-        }, headers = {})
+    def get_dy_sign(self,url,uid):
+        return self.post(f"{self.url}/api/dy/signature", data = {
+            'url': url,
+            'uid': uid
+        },headers={})
 
     def get_oss_authorization(self):
         """
@@ -166,7 +166,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get('oss/get-authorization/').json()
+        return self.get(f'{self.url}/api/oss/get-authorization/').json()
 
     def upload_software_version(self, project_id, data):
         """
@@ -177,7 +177,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.post(f'software/add-record/{project_id}/', data).json()
+        return self.post(f'{self.url}/api/software/add-record/{project_id}/', data).json()
 
     def get_dial_status(self, server_name):
         """
@@ -188,7 +188,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f'agent/{server_name}/').json()
+        return self.get(f'{self.url}/api/agent/{server_name}/').json()
 
     def get_proxy_detail(self, server_name):
         """
@@ -199,7 +199,7 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f'agent/{server_name}').json()
+        return self.get(f'{self.url}/api/agent/{server_name}/').json()
 
     def report(self, service_name, status):
         """
@@ -215,7 +215,7 @@ class MonitoringCenterService(RequestBase, ABC):
                 "status":      status,
                 "server_name": service_name,
         }
-        return self.post(f'agent/', data = data).json()
+        return self.post(f'{self.url}/api/agent/', data = data).json()
 
     def get_project_detail(self, project_id) -> dict:
         """
@@ -223,4 +223,4 @@ class MonitoringCenterService(RequestBase, ABC):
         Returns:
 
         """
-        return self.get(f'project/{project_id}').json()
+        return self.get(f'{self.url}/api/project/{project_id}/').json()
