@@ -324,6 +324,28 @@ class WeiBoPcCollectionService(RequestBase, BaseService, WeiBoBaseService, ABC):
 
         return json.loads(resp.text)
 
+    @helper("login_guest")
+    def get_likes_tourist(self,url):
+        headers = {
+            # 'user-agent': 'Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, '
+            #               'like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1',
+            # 'accept':     'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,'
+            #               'image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
+            'Cookie':     self._headers.get('Cookie', '')
+        }
+        _res = self.requests.get(url, headers = headers, timeout = self.TIMEOUT)
+        if _res.status_code != 200:
+            return '访问code错误：{0}'.format(_res.status_code)
+
+        if _res.text.find('博文涉及营销推广正在审核中，暂时无法传播') >= 0:
+            return '博文涉及营销推广正在审核中，暂时无法传播'
+        if _res.text.find('由于用户设置，你无法回复评论。') >= 0:
+            return '由于用户设置，你无法回复评论。'
+        if _res.text.find('以下为博主精选评论') >= 0:
+            return '以下为博主精选评论'
+
+        return _res.text
+
     @staticmethod
     def _unit_conversion(unit) -> int:
         """
