@@ -10,7 +10,7 @@ from dotenv import load_dotenv
 from protocol_helper.Exceptions import NotSetDirectory
 
 LOAD_PROJECT_PATH = os.environ.get('LOAD_PROJECT_PATH')
-print(LOAD_PROJECT_PATH)
+
 if LOAD_PROJECT_PATH is None:
     raise NotSetDirectory
 try:
@@ -23,3 +23,11 @@ except Exception as error:
 # Monitoring Center Configuration File
 SURVEILLANCE_SYSTEM_DOMAIN = os.getenv('SURVEILLANCE_SYSTEM_DOMAIN', None)
 SURVEILLANCE_SYSTEM_TOKEN = os.getenv('SURVEILLANCE_SYSTEM_TOKEN', None)
+
+# Log storage path
+RUNTIME = os.path.join(LOAD_PROJECT_PATH, 'runtime')
+
+# Broadband dialing information
+PPPOE_NAME = os.getenv('PPPOE_NAME', None)
+PPPOE_USER = os.getenv('PPPOE_USER', '')
+PPPOE_PASS = os.getenv('PPPOE_PASS', '')
